@@ -1,5 +1,5 @@
 import logging
-from dataclasses import dataclass, field
+from pydantic import BaseModel, Field, validator
 
 from .dialect import DEFAULT_DIALECT
 from .lib import walk_list
@@ -7,26 +7,16 @@ from .lib import walk_list
 logger = logging.getLogger(__name__)
 
 
-@dataclass
-class Query:
-    query: list = field(default_factory=list)
+class Query(BaseModel):
+    query: list = Field(default_factory=list)
     dialect: str = DEFAULT_DIALECT
 
-    def __post_init__(self):
+    @validator('query', pre=True)
+    def convert_query(cls, value):
         # allow the query to be a single string
-        if isinstance(self.query, str):
-            self.query = [self.query]
-
-    def __str__(self):
-        return ' '.join([str(q) for q in walk_list(self.query) if q]).strip()
-
-    def render(self, data=None):
-        """
-        Render the query and its values for a given data input.
-        """
-        data = data or {}
-        query_string = str(self)
-        return self.dialect.render(query_string, data)
+        if isinstance(value, str):
+            value = [value]
+        return value
 
     @classmethod
     def fields(cls, data):
@@ -42,5 +32,16 @@ class Query:
         return ', '.join(f'{key}=:{key}' for key in data if key not in excludes)
 
     @classmethod
-    def where(cls, data):
+    def filters(cls, data):
         return ' AND '.join(f'{key}=:{key}' for key in data)
+
+    def __str__(self):
+        return ' '.join([str(q) for q in walk_list(self.query) if q]).strip()
+
+    def render(self, data=None):
+        """
+        Render the query and its values for a given data input.
+        """
+        data = data or {}
+        query_string = str(self)
+        return self.dialect.render(query_string, data)
